# Welcome to SportsX SDK Documentation

# Overview

The STX SDK is a wrapper around the Sportsx Graphql APIs and Phoenix channels.
The SDK provides object-oriented APIs to connect with the available Sportsx APIs and socket channels.
The SDK is built on the following libraries:
 - GQL: https://github.com/graphql-python/gql
 - Websockets: https://github.com/aaugustin/websockets

## Compatibility

This library is compatible with the following versions of Python:

 - 3.7
 - 3.8
 - 3.9

# Developer Guide:

Detailed developer guide and demo scripts are available on this [link](https://github.com/stxapp/pysdk-demo)

There are two services available **StxClient** and **StxChannelClient**

 - **StxClient** provides sync operations, while
 - **StxChannelClient** provides connectivity with websocket channels.
